==> haskell-data-dword-0.3.2.1-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-dword
version:              0.3.2.1
visibility:           public
id:                   data-dword-0.3.2.1-B4flFNAzb5b6UboZ1dW9xN
key:                  data-dword-0.3.2.1-B4flFNAzb5b6UboZ1dW9xN
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  56092851af61ae3ea563e0bf2cfb2e12
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-dword-0.3.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-dword-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-dword-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-dword
hs-libraries:         HSdata-dword-0.3.2.1-B4flFNAzb5b6UboZ1dW9xN
depends:
    base-4.17.2.1 data-bword-0.1.0.2-AcTtELe643OD2aoByNycmZ
    ghc-prim-0.9.1 hashable-1.4.4.0-HmFtE5Wyl97MxSGTvKCoh
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.2.1-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-dword
version:              0.3.2.1
visibility:           public
id:                   data-dword-0.3.2.1-BVFIjEjUjvvDxEtmK4dTbr
key:                  data-dword-0.3.2.1-BVFIjEjUjvvDxEtmK4dTbr
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  d0c488b2b84e0065c9356acf11500511
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-dword-0.3.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-dword-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-dword-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-dword
hs-libraries:         HSdata-dword-0.3.2.1-BVFIjEjUjvvDxEtmK4dTbr
depends:
    base-4.17.2.1 data-bword-0.1.0.2-AcTtELe643OD2aoByNycmZ
    ghc-prim-0.9.1 hashable-1.4.4.0-EdBgVbn6YIuE9bA3dwmz04
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
